@@ -158,7 +158,6 @@ static const gchar *REQUIRED_GEGL_OPS[] =
   "gegl:scale-ratio",
 
   /* Used by gegl:load */
-  "gegl:jp2-load",
   "gegl:jpg-load",
   "gegl:png-load",
   "gegl:raw-load",
@@ -1626,6 +1625,7 @@ photos_application_startup (GApplication *application)
   const gchar *edit_accels[2] = {"<Primary>e", NULL};
   const gchar *fullscreen_accels[2] = {"F11", NULL};
   const gchar *gear_menu_accels[2] = {"F10", NULL};
+  const gchar *help_menu_accels[2] = {"F1", NULL};
   const gchar *print_current_accels[2] = {"<Primary>p", NULL};
   const gchar *quit_accels[2] = {"<Primary>q", NULL};
   const gchar *save_accels[2] = {"<Primary>x", NULL};
@@ -1849,6 +1849,7 @@ photos_application_startup (GApplication *application)
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.edit-current", edit_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.fullscreen", fullscreen_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.gear-menu", gear_menu_accels);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.help", help_menu_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.print-current", print_current_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.save-current", save_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.search", search_accels);
