@@ -35,12 +35,14 @@
 
 struct _PhotosBaseManagerPrivate
 {
+  GCompareDataFunc sort_func;
   GHashTable *objects;
   GObject *active_object;
   GSequence *sequence;
   GSequenceIter *last_iter;
   gchar *action_id;
   gchar *title;
+  gpointer sort_data;
   guint last_position;
 };
 
@@ -48,6 +50,8 @@ enum
 {
   PROP_0,
   PROP_ACTION_ID,
+  PROP_SORT_DATA,
+  PROP_SORT_FUNC,
   PROP_TITLE
 };
 
@@ -133,8 +137,16 @@ photos_base_manager_default_add_object (PhotosBaseManager *self, GObject *object
   if (old_object != NULL)
     return;
 
-  position = photos_base_manager_get_objects_count (self);
-  iter = g_sequence_append (priv->sequence, g_object_ref (object));
+  if (priv->sort_func == NULL)
+    {
+      position = photos_base_manager_get_objects_count (self);
+      iter = g_sequence_append (priv->sequence, g_object_ref (object));
+    }
+  else
+    {
+      iter = g_sequence_insert_sorted (priv->sequence, g_object_ref (object), priv->sort_func, priv->sort_data);
+      position = g_sequence_iter_get_position (iter);
+    }
 
   object_data = photos_base_manager_object_data_new (object, iter);
   g_hash_table_insert (priv->objects, g_strdup (id), object_data);
@@ -161,6 +173,32 @@ photos_base_manager_default_get_filter (PhotosBaseManager *self, gint flags)
 }
 
 
+static GObject *
+photos_base_manager_default_get_next_object (PhotosBaseManager *self, GObject *object)
+{
+  PhotosBaseManagerPrivate *priv;
+  GObject *ret_val = NULL;
+  GSequenceIter *iter;
+  PhotosBaseManagerObjectData *object_data;
+  const gchar *id;
+
+  priv = photos_base_manager_get_instance_private (self);
+
+  id = photos_filterable_get_id (PHOTOS_FILTERABLE (object));
+  object_data = g_hash_table_lookup (priv->objects, id);
+  g_return_val_if_fail (object_data != NULL, NULL);
+
+  iter = g_sequence_iter_next (object_data->iter);
+  if (g_sequence_iter_is_end (iter))
+    goto out;
+
+  ret_val = G_OBJECT (g_sequence_get (iter));
+
+ out:
+  return ret_val;
+}
+
+
 static GObject *
 photos_base_manager_default_get_object_by_id (PhotosBaseManager *self, const gchar *id)
 {
@@ -181,6 +219,32 @@ photos_base_manager_default_get_object_by_id (PhotosBaseManager *self, const gch
 }
 
 
+static GObject *
+photos_base_manager_default_get_previous_object (PhotosBaseManager *self, GObject *object)
+{
+  PhotosBaseManagerPrivate *priv;
+  GObject *ret_val = NULL;
+  GSequenceIter *iter;
+  PhotosBaseManagerObjectData *object_data;
+  const gchar *id;
+
+  priv = photos_base_manager_get_instance_private (self);
+
+  id = photos_filterable_get_id (PHOTOS_FILTERABLE (object));
+  object_data = g_hash_table_lookup (priv->objects, id);
+  g_return_val_if_fail (object_data != NULL, NULL);
+
+  iter = g_sequence_iter_prev (object_data->iter);
+  if (g_sequence_iter_compare (iter, object_data->iter) == 0)
+    goto out;
+
+  ret_val = G_OBJECT (g_sequence_get (iter));
+
+ out:
+  return ret_val;
+}
+
+
 static gchar *
 photos_base_manager_default_get_where (PhotosBaseManager *self, gint flags)
 {
@@ -334,6 +398,14 @@ photos_base_manager_set_property (GObject *object, guint prop_id, const GValue *
       priv->action_id = g_value_dup_string (value);
       break;
 
+    case PROP_SORT_DATA:
+      priv->sort_data = g_value_get_pointer (value);
+      break;
+
+    case PROP_SORT_FUNC:
+      priv->sort_func = g_value_get_pointer (value);
+      break;
+
     case PROP_TITLE:
       priv->title = g_value_dup_string (value);
       break;
@@ -371,7 +443,9 @@ photos_base_manager_class_init (PhotosBaseManagerClass *class)
   class->add_object = photos_base_manager_default_add_object;
   class->get_active_object = photos_base_manager_default_get_active_object;
   class->get_filter = photos_base_manager_default_get_filter;
+  class->get_next_object = photos_base_manager_default_get_next_object;
   class->get_object_by_id = photos_base_manager_default_get_object_by_id;
+  class->get_previous_object = photos_base_manager_default_get_previous_object;
   class->get_where = photos_base_manager_default_get_where;
   class->remove_object_by_id = photos_base_manager_default_remove_object_by_id;
   class->set_active_object = photos_base_manager_default_set_active_object;
@@ -384,6 +458,20 @@ photos_base_manager_class_init (PhotosBaseManagerClass *class)
                                                         NULL,
                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
 
+  g_object_class_install_property (object_class,
+                                   PROP_SORT_DATA,
+                                   g_param_spec_pointer ("sort-data",
+                                                         "Sort data",
+                                                         "Arbitrary data to be passed to the comparison function",
+                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+
+  g_object_class_install_property (object_class,
+                                   PROP_SORT_FUNC,
+                                   g_param_spec_pointer ("sort-func",
+                                                         "Sort function",
+                                                         "Pairwise comparison function for sorting",
+                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+
   g_object_class_install_property (object_class,
                                    PROP_TITLE,
                                    g_param_spec_string ("title",
@@ -447,9 +535,9 @@ photos_base_manager_list_model_iface_init (GListModelInterface *iface)
 
 
 PhotosBaseManager *
-photos_base_manager_new (void)
+photos_base_manager_new (GCompareDataFunc sort_func, gpointer sort_data)
 {
-  return g_object_new (PHOTOS_TYPE_BASE_MANAGER, NULL);
+  return g_object_new (PHOTOS_TYPE_BASE_MANAGER, "sort-data", sort_data, "sort-func", sort_func, NULL);
 }
 
 
@@ -572,6 +660,16 @@ photos_base_manager_get_filter (PhotosBaseManager *self, gint flags)
 }
 
 
+GObject *
+photos_base_manager_get_next_object (PhotosBaseManager *self, GObject *object)
+{
+  g_return_val_if_fail (PHOTOS_IS_BASE_MANAGER (self), NULL);
+  g_return_val_if_fail (PHOTOS_IS_FILTERABLE (object), NULL);
+
+  return PHOTOS_BASE_MANAGER_GET_CLASS (self)->get_next_object (self, object);
+}
+
+
 GObject *
 photos_base_manager_get_object_by_id (PhotosBaseManager *self, const gchar *id)
 {
@@ -596,6 +694,16 @@ photos_base_manager_get_objects_count (PhotosBaseManager *self)
 }
 
 
+GObject *
+photos_base_manager_get_previous_object (PhotosBaseManager *self, GObject *object)
+{
+  g_return_val_if_fail (PHOTOS_IS_BASE_MANAGER (self), NULL);
+  g_return_val_if_fail (PHOTOS_IS_FILTERABLE (object), NULL);
+
+  return PHOTOS_BASE_MANAGER_GET_CLASS (self)->get_previous_object (self, object);
+}
+
+
 const gchar *
 photos_base_manager_get_title (PhotosBaseManager *self)
 {
