@@ -68,6 +68,11 @@ photos_camera_cache_cursor_next (GObject *source_object, GAsyncResult *res, gpoi
       goto out;
     }
 
+  /* Note that the following SPARQL query:
+   *   SELECT nfo:manufacturer (<(foo)>) nfo:model (<(foo)>) WHERE {}
+   * ... will not return an empty cursor, but:
+   *   (null), (null)
+   */
   if (!success)
     {
       g_task_return_new_error (task, PHOTOS_ERROR, 0, "Cursor is empty — possibly wrong SPARQL query");
@@ -102,7 +107,7 @@ photos_camera_cache_equipment_query_executed (GObject *source_object, GAsyncResu
 {
   GTask *task = G_TASK (user_data);
   TrackerSparqlConnection *connection = TRACKER_SPARQL_CONNECTION (source_object);
-  TrackerSparqlCursor *cursor;
+  TrackerSparqlCursor *cursor = NULL;
   GError *error;
 
   error = NULL;
@@ -110,11 +115,13 @@ photos_camera_cache_equipment_query_executed (GObject *source_object, GAsyncResu
   if (error != NULL)
     {
       g_task_return_error (task, error);
-      return;
+      goto out;
     }
 
   tracker_sparql_cursor_next_async (cursor, NULL, photos_camera_cache_cursor_next, g_object_ref (task));
-  g_object_unref (cursor);
+
+ out:
+  g_clear_object (&cursor);
 }
 
 
