@@ -32,6 +32,7 @@
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 
+#include "photos-base-item.h"
 #include "photos-embed.h"
 #include "photos-filterable.h"
 #include "photos-item-manager.h"
@@ -249,11 +250,15 @@ static void
 photos_embed_prepare_for_preview (PhotosEmbed *self, PhotosWindowMode old_mode)
 {
   PhotosBaseItem *active_collection;
+  PhotosBaseItem *item;
 
   /* TODO: SearchController,
    *       ErrorHandler
    */
 
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->item_mngr));
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (item));
+
   /* We want to freeze before saving the search state and to thaw
    * after restoring it. We could thaw it earlier too, but that would
    * lead to a bunch of needless queries from the TrackerControllers.
@@ -283,16 +288,7 @@ photos_embed_prepare_for_preview (PhotosEmbed *self, PhotosWindowMode old_mode)
    * when returning from the edit mode.
    */
   if (old_mode != PHOTOS_WINDOW_MODE_NONE && old_mode != PHOTOS_WINDOW_MODE_EDIT)
-    {
-      GtkListStore *model;
-      GtkTreePath *current_path;
-      GtkWidget *view_container;
-
-      view_container = photos_embed_get_view_container_from_mode (self, old_mode);
-      current_path = photos_view_container_get_current_path (PHOTOS_VIEW_CONTAINER (view_container));
-      model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
-      photos_preview_view_set_model (PHOTOS_PREVIEW_VIEW (self->preview), GTK_TREE_MODEL (model), current_path);
-    }
+    photos_preview_view_set_mode (PHOTOS_PREVIEW_VIEW (self->preview), old_mode);
 
   if (old_mode != PHOTOS_WINDOW_MODE_EDIT)
     photos_preview_view_set_node (PHOTOS_PREVIEW_VIEW (self->preview), NULL);
@@ -469,28 +465,6 @@ photos_embed_query_status_changed (PhotosEmbed *self, gboolean querying)
 }
 
 
-static void
-photos_embed_row_changed (PhotosEmbed *self)
-{
-  PhotosWindowMode mode;
-
-  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
-
-  if (mode == PHOTOS_WINDOW_MODE_COLLECTIONS
-      || mode == PHOTOS_WINDOW_MODE_FAVORITES
-      || mode == PHOTOS_WINDOW_MODE_OVERVIEW
-      || mode == PHOTOS_WINDOW_MODE_SEARCH)
-    {
-      GtkListStore *model;
-      GtkWidget *view_container;
-
-      view_container = photos_embed_get_view_container_from_mode (self, mode);
-      model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
-      photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (self->toolbar), PHOTOS_VIEW_MODEL (model));
-    }
-}
-
-
 static void
 photos_embed_search_changed (PhotosEmbed *self)
 {
@@ -541,8 +515,6 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
                                   gpointer user_data)
 {
   PhotosEmbed *self = PHOTOS_EMBED (user_data);
-  GtkListStore *model;
-  GtkWidget *view_container;
 
   photos_main_toolbar_reset_toolbar_mode (PHOTOS_MAIN_TOOLBAR (self->toolbar));
 
@@ -553,15 +525,15 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
 
     case PHOTOS_WINDOW_MODE_COLLECTIONS:
       photos_embed_prepare_for_collections (self, old_mode);
-      goto set_toolbar_model;
+      break;
 
     case PHOTOS_WINDOW_MODE_FAVORITES:
       photos_embed_prepare_for_favorites (self, old_mode);
-      goto set_toolbar_model;
+      break;
 
     case PHOTOS_WINDOW_MODE_OVERVIEW:
       photos_embed_prepare_for_overview (self, old_mode);
-      goto set_toolbar_model;
+      break;
 
     case PHOTOS_WINDOW_MODE_PREVIEW:
       photos_embed_prepare_for_preview (self, old_mode);
@@ -569,7 +541,7 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
 
     case PHOTOS_WINDOW_MODE_SEARCH:
       photos_embed_prepare_for_search (self, old_mode);
-      goto set_toolbar_model;
+      break;
 
     case PHOTOS_WINDOW_MODE_NONE:
     default:
@@ -578,11 +550,6 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
     }
 
   return;
-
- set_toolbar_model:
-  view_container = photos_embed_get_view_container_from_mode (self, mode);
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
-  photos_main_toolbar_set_view_model (PHOTOS_MAIN_TOOLBAR (self->toolbar), PHOTOS_VIEW_MODEL (model));
 }
 
 
@@ -602,19 +569,6 @@ photos_embed_dispose (GObject *object)
   g_clear_object (&self->srch_cntrlr);
   g_clear_object (&self->trk_ovrvw_cntrlr);
 
-  /* GtkStack triggers notify::visible-child during dispose and this means that
-   * we have to explicitly disconnect the signal handler before calling up to
-   * the parent implementation, or photos_embed_notify_visible_child() will
-   * get called while we're in a inconsistent state
-   *
-   * See https://bugzilla.gnome.org/show_bug.cgi?id=749012
-   */
-  if (self->stack != NULL)
-    {
-      g_signal_handlers_disconnect_by_func (self->stack, photos_embed_notify_visible_child, self);
-      self->stack = NULL;
-    }
-
   G_OBJECT_CLASS (photos_embed_parent_class)->dispose (object);
 }
 
@@ -624,7 +578,6 @@ photos_embed_init (PhotosEmbed *self)
 {
   GApplication *app;
   GList *windows;
-  GtkListStore *model;
   PhotosSearchbar *searchbar;
   PhotosSearchContextState *state;
   gboolean querying;
@@ -666,29 +619,17 @@ photos_embed_init (PhotosEmbed *self)
   self->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW, _("Photos"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->overview));
   gtk_stack_add_titled (GTK_STACK (self->stack), self->overview, "overview", name);
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->overview));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
   self->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS, _("Albums"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->collections));
   gtk_stack_add_titled (GTK_STACK (self->stack), self->collections, "collections", name);
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->collections));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
   self->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES, _("Favorites"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->favorites));
   gtk_stack_add_titled (GTK_STACK (self->stack), self->favorites, "favorites", name);
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->favorites));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
   self->search = photos_view_container_new (PHOTOS_WINDOW_MODE_SEARCH, _("Search"));
   gtk_stack_add_named (GTK_STACK (self->stack), self->search, "search");
-  model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (self->search));
-  g_signal_connect_object (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
-  g_signal_connect_object (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self, G_CONNECT_SWAPPED);
 
   self->preview = photos_preview_view_new (GTK_OVERLAY (self->stack_overlay));
   gtk_stack_add_named (GTK_STACK (self->stack), self->preview, "preview");
