@@ -44,11 +44,6 @@ struct _PhotosFetchIdsJob
   gchar **terms;
 };
 
-struct _PhotosFetchIdsJobClass
-{
-  GObjectClass parent_class;
-};
-
 enum
 {
   PROP_0,
@@ -73,6 +68,9 @@ photos_fetch_ids_job_cursor_next (GObject *source_object, GAsyncResult *res, gpo
   cancellable = g_task_get_cancellable (task);
 
   error = NULL;
+  /* Note that tracker_sparql_cursor_next_finish can return FALSE even
+   * without an error.
+   */
   success = tracker_sparql_cursor_next_finish (cursor, res, &error);
   if (error != NULL)
     {
