@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -62,6 +62,7 @@ struct _PhotosItemManager
   PhotosTrackerChangeMonitor *monitor;
   PhotosWindowMode mode;
   gboolean fullscreen;
+  gboolean *constrain_additions;
 };
 
 struct _PhotosItemManagerClass
@@ -142,12 +143,223 @@ photos_item_manager_add_object (PhotosBaseManager *mngr, GObject *object)
 }
 
 
+static gboolean
+photos_item_manager_can_add_mtime_for_mode (PhotosItemManager *self, gint64 mtime, PhotosWindowMode mode)
+{
+  PhotosBaseItem *oldest_item = NULL;
+  PhotosBaseManager *item_mngr_chld;
+  gboolean ret_val = TRUE;
+  gint64 oldest_mtime;
+  guint n_items;
+
+  if (!self->constrain_additions[mode])
+    goto out;
+
+  item_mngr_chld = self->item_mngr_chldrn[mode];
+  n_items = g_list_model_get_n_items (G_LIST_MODEL (item_mngr_chld));
+  if (n_items == 0)
+    goto out;
+
+  oldest_item = PHOTOS_BASE_ITEM (g_list_model_get_object (G_LIST_MODEL (item_mngr_chld), n_items - 1));
+  oldest_mtime = photos_base_item_get_mtime (oldest_item);
+
+  if (mtime > oldest_mtime)
+    goto out;
+
+  ret_val = FALSE;
+
+ out:
+  g_clear_object (&oldest_item);
+  return ret_val;
+}
+
+
+static gboolean
+photos_item_manager_can_add_cursor_for_mode (PhotosItemManager *self,
+                                             TrackerSparqlCursor *cursor,
+                                             PhotosWindowMode mode)
+{
+  gboolean ret_val = TRUE;
+  gint64 mtime;
+
+  mtime = tracker_sparql_cursor_get_boolean (cursor, PHOTOS_QUERY_COLUMNS_MTIME);
+  ret_val = photos_item_manager_can_add_mtime_for_mode (self, mtime, mode);
+  return ret_val;
+}
+
+
+static gboolean
+photos_item_manager_can_add_item_for_mode (PhotosItemManager *self, PhotosBaseItem *item, PhotosWindowMode mode)
+{
+  gboolean ret_val = TRUE;
+  gint64 mtime;
+
+  mtime = photos_base_item_get_mtime (item);
+  ret_val = photos_item_manager_can_add_mtime_for_mode (self, mtime, mode);
+  return ret_val;
+}
+
+
+static gboolean
+photos_item_manager_cursor_is_collection (TrackerSparqlCursor *cursor)
+{
+  gboolean ret_val;
+  const gchar *rdf_type;
+
+  rdf_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL);
+  ret_val = strstr (rdf_type, "nfo#DataContainer") != NULL;
+  return ret_val;
+}
+
+
+static gboolean
+photos_item_manager_try_to_add_item_for_mode (PhotosItemManager *self,
+                                              PhotosBaseItem *item,
+                                              PhotosWindowMode mode)
+{
+  gboolean ret_val = FALSE;
+
+  g_return_val_if_fail (PHOTOS_IS_ITEM_MANAGER (self), FALSE);
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (item), FALSE);
+  g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_NONE, FALSE);
+  g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT, FALSE);
+  g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW, FALSE);
+
+  if (!photos_item_manager_can_add_item_for_mode (self, item, mode))
+    goto out;
+
+  photos_base_manager_add_object (self->item_mngr_chldrn[mode], G_OBJECT (item));
+  ret_val = TRUE;
+
+ out:
+  return ret_val;
+}
+
+
+static void
+photos_item_manager_info_updated (PhotosBaseItem *item, gpointer user_data)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (user_data);
+  PhotosBaseItem *updated_item;
+  gboolean is_collection;
+  gboolean is_favorite;
+  const gchar *id;
+
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (item));
+
+  id = photos_filterable_get_id (PHOTOS_FILTERABLE (item));
+  updated_item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), id));
+  if (updated_item == NULL)
+    return;
+
+  g_return_if_fail (updated_item == item);
+
+  is_collection = photos_base_item_is_collection (item);
+  is_favorite = photos_base_item_is_favorite (item);
+
+  if (is_collection)
+    {
+      if (self->active_collection == NULL)
+        photos_item_manager_try_to_add_item_for_mode (self, item, PHOTOS_WINDOW_MODE_COLLECTIONS);
+    }
+  else
+    {
+      if (is_favorite)
+        photos_item_manager_try_to_add_item_for_mode (self, item, PHOTOS_WINDOW_MODE_FAVORITES);
+
+      photos_item_manager_try_to_add_item_for_mode (self, item, PHOTOS_WINDOW_MODE_OVERVIEW);
+    }
+
+  if (is_collection)
+    {
+      photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_FAVORITES], G_OBJECT (item));
+      photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_OVERVIEW], G_OBJECT (item));
+    }
+  else
+    {
+      if (self->active_collection == NULL)
+        photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_COLLECTIONS], G_OBJECT (item));
+
+      if (!is_favorite)
+        photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_FAVORITES], G_OBJECT (item));
+    }
+}
+
+
+static void
+photos_item_manager_add_cursor_for_mode (PhotosItemManager *self,
+                                         TrackerSparqlCursor *cursor,
+                                         PhotosWindowMode mode,
+                                         gboolean force)
+{
+  PhotosBaseItem *item = NULL;
+  PhotosBaseManager *item_mngr_chld;
+  gboolean is_collection;
+  const gchar *id;
+
+  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
+  g_return_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor));
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT);
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
+
+  is_collection = photos_item_manager_cursor_is_collection (cursor);
+  g_return_if_fail ((is_collection
+                     && (mode == PHOTOS_WINDOW_MODE_COLLECTIONS || mode == PHOTOS_WINDOW_MODE_SEARCH))
+                    || (!is_collection
+                        && (mode != PHOTOS_WINDOW_MODE_COLLECTIONS || self->active_collection != NULL)));
+
+  if (!force && !photos_item_manager_can_add_cursor_for_mode (self, cursor, mode))
+    goto out;
+
+  item_mngr_chld = self->item_mngr_chldrn[mode];
+  id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
+
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (item_mngr_chld, id));
+  if (item != NULL)
+    {
+      g_object_ref (item);
+    }
+  else
+    {
+      gboolean already_present = FALSE;
+
+      item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), id));
+      if (item != NULL)
+        {
+          g_object_ref (item);
+          already_present = TRUE;
+        }
+      else
+        {
+          item = photos_item_manager_create_item (self, cursor);
+          if (photos_base_item_is_collection (item))
+            g_hash_table_insert (self->collections, g_strdup (id), g_object_ref (item));
+
+          g_signal_connect_object (item, "info-updated", G_CALLBACK (photos_item_manager_info_updated), self, 0);
+        }
+
+      photos_base_manager_add_object (item_mngr_chld, G_OBJECT (item));
+      photos_base_manager_add_object (self->item_mngr_chldrn[0], G_OBJECT (item));
+
+      if (!already_present)
+        g_signal_emit_by_name (self, "object-added", G_OBJECT (item));
+    }
+
+ out:
+  g_clear_object (&item);
+}
+
+
 static void
 photos_item_manager_check_wait_for_changes (PhotosItemManager *self, const gchar *id, const gchar *uri)
 {
   GList *l;
   GList *tasks;
 
+  g_return_if_fail (id != NULL && id[0] != '\0');
+  g_return_if_fail (uri != NULL && uri[0] != '\0');
+
   tasks = (GList *) g_hash_table_lookup (self->wait_for_changes_table, uri);
   for (l = tasks; l != NULL; l = l->next)
     {
@@ -166,8 +378,6 @@ photos_item_manager_item_created_executed (GObject *source_object, GAsyncResult
   GError *error = NULL;
   PhotosSingleItemJob *job = PHOTOS_SINGLE_ITEM_JOB (source_object);
   TrackerSparqlCursor *cursor = NULL;
-  const gchar *id;
-  const gchar *uri;
 
   cursor = photos_single_item_job_finish (job, res, &error);
   if (error != NULL)
@@ -182,9 +392,15 @@ photos_item_manager_item_created_executed (GObject *source_object, GAsyncResult
 
   photos_item_manager_add_item (self, cursor, FALSE);
 
-  id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
-  uri = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URI, NULL);
-  photos_item_manager_check_wait_for_changes (self, id, uri);
+  if (!photos_item_manager_cursor_is_collection (cursor))
+    {
+      const gchar *id;
+      const gchar *uri;
+
+      id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
+      uri = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URI, NULL);
+      photos_item_manager_check_wait_for_changes (self, id, uri);
+    }
 
  out:
   g_clear_object (&cursor);
@@ -235,12 +451,15 @@ photos_item_manager_changes_pending_foreach (gpointer key, gpointer value, gpoin
       object = photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), change_urn);
       if (object != NULL)
         {
-          const gchar *uri;
-
           photos_base_item_refresh (PHOTOS_BASE_ITEM (object));
 
-          uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (object));
-          photos_item_manager_check_wait_for_changes (self, change_urn, uri);
+          if (!photos_base_item_is_collection (PHOTOS_BASE_ITEM (object)))
+	    {
+              const gchar *uri;
+
+              uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (object));
+              photos_item_manager_check_wait_for_changes (self, change_urn, uri);
+	    }
         }
     }
   else if (change_type == PHOTOS_TRACKER_CHANGE_EVENT_CREATED)
@@ -295,18 +514,6 @@ photos_item_manager_collection_path_free (PhotosItemManager *self)
 }
 
 
-static gboolean
-photos_item_manager_cursor_is_collection (TrackerSparqlCursor *cursor)
-{
-  gboolean ret_val;
-  const gchar *rdf_type;
-
-  rdf_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL);
-  ret_val = strstr (rdf_type, "nfo#DataContainer") != NULL;
-  return ret_val;
-}
-
-
 static gboolean
 photos_item_manager_cursor_is_favorite (TrackerSparqlCursor *cursor)
 {
@@ -382,56 +589,6 @@ photos_item_manager_get_where (PhotosBaseManager *mngr, gint flags)
 }
 
 
-static void
-photos_item_manager_info_updated (PhotosBaseItem *item, gpointer user_data)
-{
-  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (user_data);
-  PhotosBaseItem *updated_item;
-  gboolean is_collection;
-  gboolean is_favorite;
-  const gchar *id;
-
-  g_return_if_fail (PHOTOS_IS_BASE_ITEM (item));
-
-  id = photos_filterable_get_id (PHOTOS_FILTERABLE (item));
-  updated_item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), id));
-  if (updated_item == NULL)
-    return;
-
-  g_return_if_fail (updated_item == item);
-
-  is_collection = photos_base_item_is_collection (item);
-  is_favorite = photos_base_item_is_favorite (item);
-
-  if (is_collection)
-    {
-      if (self->active_collection == NULL)
-        photos_base_manager_add_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_COLLECTIONS], G_OBJECT (item));
-    }
-  else
-    {
-      if (is_favorite)
-        photos_base_manager_add_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_FAVORITES], G_OBJECT (item));
-
-      photos_base_manager_add_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_OVERVIEW], G_OBJECT (item));
-    }
-
-  if (is_collection)
-    {
-      photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_FAVORITES], G_OBJECT (item));
-      photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_OVERVIEW], G_OBJECT (item));
-    }
-  else
-    {
-      if (self->active_collection == NULL)
-        photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_COLLECTIONS], G_OBJECT (item));
-
-      if (!is_favorite)
-        photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_FAVORITES], G_OBJECT (item));
-    }
-}
-
-
 static void
 photos_item_manager_item_load (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -672,6 +829,7 @@ photos_item_manager_finalize (GObject *object)
   PhotosItemManager *self = PHOTOS_ITEM_MANAGER (object);
 
   g_queue_free (self->history);
+  g_free (self->constrain_additions);
 
   G_OBJECT_CLASS (photos_item_manager_parent_class)->finalize (object);
 
@@ -701,6 +859,7 @@ photos_item_manager_init (PhotosItemManager *self)
   self->history = g_queue_new ();
 
   window_mode_class = G_ENUM_CLASS (g_type_class_ref (PHOTOS_TYPE_WINDOW_MODE));
+
   self->item_mngr_chldrn = (PhotosBaseManager **) g_malloc0_n (window_mode_class->n_values + 1,
                                                                sizeof (PhotosBaseManager *));
   for (i = 0; i < window_mode_class->n_values; i++)
@@ -722,6 +881,7 @@ photos_item_manager_init (PhotosItemManager *self)
                              G_CONNECT_SWAPPED);
 
   self->fullscreen = FALSE;
+  self->constrain_additions = (gboolean *) g_malloc0_n (window_mode_class->n_values, sizeof (gboolean));
 
   g_type_class_unref (window_mode_class);
 }
@@ -870,14 +1030,14 @@ photos_item_manager_add_item (PhotosItemManager *self, TrackerSparqlCursor *curs
         photos_item_manager_activate_previous_collection (self);
 
       if (self->active_collection == NULL)
-        photos_item_manager_add_item_for_mode (self, PHOTOS_WINDOW_MODE_COLLECTIONS, cursor);
+        photos_item_manager_add_cursor_for_mode (self, cursor, PHOTOS_WINDOW_MODE_COLLECTIONS, force);
     }
   else
     {
       if (photos_item_manager_cursor_is_favorite (cursor))
-        photos_item_manager_add_item_for_mode (self, PHOTOS_WINDOW_MODE_FAVORITES, cursor);
+        photos_item_manager_add_cursor_for_mode (self, cursor, PHOTOS_WINDOW_MODE_FAVORITES, force);
 
-      photos_item_manager_add_item_for_mode (self, PHOTOS_WINDOW_MODE_OVERVIEW, cursor);
+      photos_item_manager_add_cursor_for_mode (self, cursor, PHOTOS_WINDOW_MODE_OVERVIEW, force);
     }
 }
 
@@ -885,56 +1045,7 @@ photos_item_manager_add_item (PhotosItemManager *self, TrackerSparqlCursor *curs
 void
 photos_item_manager_add_item_for_mode (PhotosItemManager *self, PhotosWindowMode mode, TrackerSparqlCursor *cursor)
 {
-  PhotosBaseItem *item = NULL;
-  PhotosBaseManager *item_mngr_chld;
-  gboolean is_collection;
-  const gchar *id;
-
-  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
-  g_return_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor));
-  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
-  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT);
-  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
-
-  is_collection = photos_item_manager_cursor_is_collection (cursor);
-  g_return_if_fail ((is_collection && (mode == PHOTOS_WINDOW_MODE_COLLECTIONS || mode == PHOTOS_WINDOW_MODE_SEARCH))
-                    || (!is_collection && (mode != PHOTOS_WINDOW_MODE_COLLECTIONS || self->active_collection != NULL)));
-
-  item_mngr_chld = self->item_mngr_chldrn[mode];
-  id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
-
-  item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (item_mngr_chld, id));
-  if (item != NULL)
-    {
-      g_object_ref (item);
-    }
-  else
-    {
-      gboolean already_present = FALSE;
-
-      item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), id));
-      if (item != NULL)
-        {
-          g_object_ref (item);
-          already_present = TRUE;
-        }
-      else
-        {
-          item = photos_item_manager_create_item (self, cursor);
-          if (photos_base_item_is_collection (item))
-            g_hash_table_insert (self->collections, g_strdup (id), g_object_ref (item));
-
-          g_signal_connect_object (item, "info-updated", G_CALLBACK (photos_item_manager_info_updated), self, 0);
-        }
-
-      photos_base_manager_add_object (item_mngr_chld, G_OBJECT (item));
-      photos_base_manager_add_object (self->item_mngr_chldrn[0], G_OBJECT (item));
-
-      if (!already_present)
-        g_signal_emit_by_name (self, "object-added", G_OBJECT (item));
-    }
-
-  g_clear_object (&item);
+  photos_item_manager_add_cursor_for_mode (self, cursor, mode, FALSE);
 }
 
 
@@ -1112,10 +1223,23 @@ photos_item_manager_hide_item (PhotosItemManager *self, PhotosBaseItem *item)
 }
 
 
+void
+photos_item_manager_set_constraints_for_mode (PhotosItemManager *self, gboolean constrain, PhotosWindowMode mode)
+{
+  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT);
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
+
+  self->constrain_additions[mode] = constrain;
+}
+
+
 void
 photos_item_manager_unhide_item (PhotosItemManager *self, PhotosBaseItem *item)
 {
   PhotosItemManagerHiddenItem *hidden_item;
+  gboolean added_somewhere = FALSE;
   const gchar *id;
   guint i;
 
@@ -1128,17 +1252,22 @@ photos_item_manager_unhide_item (PhotosItemManager *self, PhotosBaseItem *item)
   hidden_item = (PhotosItemManagerHiddenItem *) g_hash_table_lookup (self->hidden_items, id);
   g_return_if_fail (hidden_item->item == item);
 
-  for (i = 0; self->item_mngr_chldrn[i] != NULL; i++)
+  for (i = 1; self->item_mngr_chldrn[i] != NULL; i++)
     {
       g_assert_cmpuint (i, <, hidden_item->n_modes);
 
       if (hidden_item->modes[i])
-        photos_base_manager_add_object (self->item_mngr_chldrn[i], G_OBJECT (item));
+        added_somewhere = added_somewhere || photos_item_manager_try_to_add_item_for_mode (self, item, i);
     }
 
   g_hash_table_remove (self->hidden_items, id);
-  g_signal_connect_object (item, "info-updated", G_CALLBACK (photos_item_manager_info_updated), self, 0);
-  g_signal_emit_by_name (self, "object-added", G_OBJECT (item));
+
+  if (added_somewhere)
+    {
+      photos_base_manager_add_object (self->item_mngr_chldrn[0], G_OBJECT (item));
+      g_signal_connect_object (item, "info-updated", G_CALLBACK (photos_item_manager_info_updated), self, 0);
+      g_signal_emit_by_name (self, "object-added", G_OBJECT (item));
+    }
 }
 
 
@@ -1160,7 +1289,7 @@ photos_item_manager_wait_for_changes_async (PhotosItemManager *self,
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, photos_item_manager_wait_for_changes_async);
 
-  if (!PHOTOS_IS_LOCAL_ITEM (item))
+  if (!PHOTOS_IS_LOCAL_ITEM (item) || photos_base_item_is_collection (item))
     {
       const gchar *id;
 
