@@ -28,7 +28,6 @@
 #include <gtk/gtk.h>
 
 #include "photos-searchbar.h"
-#include "photos-view-model.h"
 
 G_BEGIN_DECLS
 
@@ -59,8 +58,6 @@ void                   photos_main_toolbar_reset_toolbar_mode     (PhotosMainToo
 
 void                   photos_main_toolbar_set_stack              (PhotosMainToolbar *self, GtkStack *stack);
 
-void                   photos_main_toolbar_set_view_model         (PhotosMainToolbar *self, PhotosViewModel *model);
-
 G_END_DECLS
 
 #endif /* PHOTOS_MAIN_TOOLBAR_H */
