@@ -33,7 +33,6 @@
 #include "photos-icons.h"
 #include "photos-preview-nav-buttons.h"
 #include "photos-search-context.h"
-#include "photos-view-model.h"
 
 
 struct _PhotosPreviewNavButtons
@@ -58,11 +57,6 @@ struct _PhotosPreviewNavButtons
   guint motion_id;
 };
 
-struct _PhotosPreviewNavButtonsClass
-{
-  GObjectClass parent_class;
-};
-
 enum
 {
   PROP_0,
