@@ -188,7 +188,8 @@ photos_query_builder_query (PhotosSearchContextState *state,
                         "nmm:fnumber (?urn) "
                         "nmm:focalLength (?urn) "
                         "nmm:isoSpeed (?urn) "
-                        "nmm:flash (?urn) ",
+                        "nmm:flash (?urn) "
+                        "slo:location (?urn) ",
                         where_sparql,
                         tail_sparql,
                         NULL);
@@ -298,6 +299,16 @@ photos_query_builder_global_query (PhotosSearchContextState *state,
 }
 
 
+PhotosQuery *
+photos_query_builder_location_query (PhotosSearchContextState *state, const gchar *location_urn)
+{
+  gchar *sparql;
+
+  sparql = g_strdup_printf ("SELECT slo:latitude (<%s>) slo:longitude (<%s>) WHERE {}", location_urn, location_urn);
+  return photos_query_new (state, sparql);
+}
+
+
 PhotosQuery *
 photos_query_builder_set_collection_query (PhotosSearchContextState *state,
                                            const gchar *item_urn,
