@@ -56,7 +56,8 @@ typedef enum
   PHOTOS_QUERY_COLUMNS_FNUMBER,
   PHOTOS_QUERY_COLUMNS_FOCAL_LENGTH,
   PHOTOS_QUERY_COLUMNS_ISO_SPEED,
-  PHOTOS_QUERY_COLUMNS_FLASH
+  PHOTOS_QUERY_COLUMNS_FLASH,
+  PHOTOS_QUERY_COLUMNS_LOCATION
 } PhotosQueryColumns;
 
 typedef enum
