@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,6 +38,9 @@
 
 #include "photos-base-item.h"
 #include "photos-base-manager.h"
+#include "photos-item-manager.h"
+#include "photos-offset-controller.h"
+#include "photos-tracker-controller.h"
 
 G_BEGIN_DECLS
 
@@ -146,6 +149,10 @@ GQuark           photos_utils_flash_off_quark             (void);
 
 GQuark           photos_utils_flash_on_quark              (void);
 
+void             photos_utils_get_controller              (PhotosWindowMode mode,
+                                                           PhotosOffsetController **out_offset_cntrlr,
+                                                           PhotosTrackerController **out_trk_cntrlr);
+
 gchar           *photos_utils_get_extension_from_mime_type (const gchar *mime_type);
 
 
@@ -159,7 +166,7 @@ const gchar     *photos_utils_get_provider_name           (PhotosBaseManager *sr
 
 GtkBorder       *photos_utils_get_thumbnail_frame_border  (void);
 
-GList           *photos_utils_get_urns_from_paths         (GList *paths, GtkTreeModel *model);
+GList           *photos_utils_get_urns_from_items         (GList *items);
 
 GIcon           *photos_utils_icon_from_rdf_type          (const gchar *type);
 
